@@ -3,7 +3,7 @@
 import re
 import warnings
 from enum import Enum
-from typing import Dict, Literal, Optional, Union
+from typing import Dict, Literal, Optional, Protocol, Union
 
 from outcome.utils import env
 from outcome.utils.config import Config
@@ -13,6 +13,11 @@ from rich.table import Table
 StateSource = Literal['config', 'default']
 
 
+class FeatureSetModule(Protocol):  # pragma: no cover
+    def display_features(self) -> None:
+        ...
+
+
 class FeatureException(Exception):
     ...
 
@@ -40,7 +45,7 @@ def reset():
 reset()
 
 
-def _is_valid_feature_name(feature: str):
+def _is_valid_feature_name(feature: str) -> bool:
     return all(re.match(_feature_pattern, part) is not None for part in feature.split('.'))
 
 
@@ -53,7 +58,7 @@ def _coerce_boolean(v: object) -> bool:
     return str(v).lower() in {'yes', 'y', 'true', 't', '1'}
 
 
-def set_config(config: Config):
+def set_config(config: Config) -> None:
     global _config
     _config = config  # noqa: WPS122,WPS442
 
@@ -81,7 +86,7 @@ def features() -> Dict[str, bool]:
     return {k: is_active(k) for k in _features.keys()}
 
 
-def display_features():  # pragma: no cover
+def display_features() -> None:  # pragma: no cover
     console = Console()
 
     table = Table(show_header=True, header_style='bold')
@@ -158,7 +163,7 @@ def _feature_state_source(feature: str) -> StateSource:
     return 'config'
 
 
-def _feature_check(feature: str):
+def _feature_check(feature: str) -> bool:
     if feature not in _features:
         if env.is_dev():
             warnings.warn(
