@@ -4,7 +4,8 @@ Responsable for adding all of the filters to the Jinja
 Environment object.
 """
 
-from jinja2.ext import Environment, Extension
+from jinja2 import Environment
+from jinja2.ext import Extension
 from outcome.utils.jinja2.regex_replace import regex_replace
 
 
