@@ -1,13 +1,13 @@
 """Helpers to manipulate class arguments."""
 
 from inspect import getclasstree, getfullargspec
-from typing import Iterable, Set, Union
+from typing import Iterable, List, Set, Union
 
 __all__ = ['get_init_args']
 
 
-def get_all_subclasses(cls: type):
-    all_subclasses = []
+def get_all_subclasses(cls: type) -> List[type]:
+    all_subclasses: List[type] = []
 
     for subclass in cls.__subclasses__():
         all_subclasses.append(subclass)
@@ -26,7 +26,9 @@ def get_init_args(cls: type) -> Set[str]:
     for cl in list_classes:
         # `getfullargspec` allows to get the arguments of a specific function - here we use
         # it on the __init__ function that initializes instances of a class
-        list_args.update(getfullargspec(cl.__init__).args)  # noqa: WPS609
+        argspec = getfullargspec(cl.__init__)  # noqa: WPS609
+        list_args.update(argspec.args)
+        list_args.update(argspec.kwonlyargs)
 
     # Remove special args
     list_args.remove('self')  # Represents the instance of the class - can't be used to create a new instance
